/*
 * $Id: migprep72.sql 84480 2007-07-24 06:34:27Z pca $
 *
 * Prepare to migrate a ManageSoft 6.6 database into ManageSoft 7.0 format.
 *
 * Use this first, then schema.sql, OpQueries.sql, then migpost.sql, and finally
 * install Managesoft 7.2 which will create the stored procedures.
 *
 * The aim here is to make minimal changes that will allow schema.sql
 * to succeed in creating any new objects, before migpost.sql finishes
 * reshaping some tables and dropping any unused objects.
 *
 * Copyright 1995-2003 ManageSoft Corporation Ltd ABN 40 052 412 156. All rights reserved.
 */

USE ManageSoft
GO



--

-- Create tables the have lists of the tables, views and stored procedures from the ManageSoft product
--
IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'ManageSoftMigration'
)
BEGIN
	TRUNCATE TABLE ManageSoftMigration 
	DROP TABLE ManageSoftMigration 
END
CREATE TABLE ManageSoftMigration (
		-- Name of table/stored procedure/view
		[Name]	nvarchar(128),

		-- Type of object - table, procedure or view
		Type	nvarchar(32)
	);
GO

-- PROCEDURES -- 
INSERT INTO ManageSoftMigration VALUES ('ActionAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesGetAllByActionUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesGetByActionUIDComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesGetByActionUIDDeviceID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesGetByActionUIDDNSName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesGetByActionUIDIPAddress', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesGetByActionUIDMACAddress', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesPutByActionUIDDeviceID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesRemoveAllByActionUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesRemoveByActionUIDComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesRemoveByActionUIDDeviceID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesRemoveByActionUIDDNSName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesRemoveByActionUIDIPAddress', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesRemoveByActionUIDMACAddress', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesReplaceSubsetByActionUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesUpdateBatchByActionUIDComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesUpdateBatchByActionUIDDeviceID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesUpdateBatchByActionUIDDNSName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesUpdateBatchByActionUIDIPAddress', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesUpdateBatchByActionUIDMACAddress', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesUpdateByActionUIDComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesUpdateByActionUIDDeviceID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesUpdateByActionUIDDNSName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesUpdateByActionUIDIPAddress', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionAppliesUpdateByActionUIDMACAddress', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionGetAllByTaskID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionGetByTaskIDServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionGetByUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionPutByUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionRemoveAllByTaskID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionRemoveByTaskIDServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionRemoveByUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionReplaceSubsetByTaskID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionStateBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionStateGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionStateGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionStateGetByName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionUpdateBatchByUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ActionUpdateByUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADComputerAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADComputerAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADComputerGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADComputerGetAllByDomainID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADComputerGetByDomainIDRDN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADComputerGetByGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADComputerPutByDomainIDRDN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADComputerRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADComputerRemoveAllByDomainID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADComputerRemoveByDomainIDRDN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADComputerRemoveByGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADComputerReplaceSubsetByDomainID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADComputerSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADComputerTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADComputerUpdateBatchByDomainIDRDN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADComputerUpdateByDomainIDRDN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('AddNetworkDevice', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADLoadDomain', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('AdministrationAccountAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('AdministrationAccountAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('AdministrationAccountBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('AdministrationAccountGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('AdministrationAccountGetByAccountName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('AdministrationAccountGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('AdministrationAccountRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('AdministrationAccountRemoveByAccountName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('AdministrationAccountRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('AdministrationAccountSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('AdministrationAccountTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('AdministrationAccountUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('AdministrationAccountUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('AdoptionStatusDetails', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('AdoptionStatusSummary', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADReconcileAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADSDOUAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADSDOUAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADSDOUGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADSDOUGetAllByDomainID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADSDOUGetByDomainIDRDN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADSDOUGetByGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADSDOUPutByDomainIDRDN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADSDOURemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADSDOURemoveAllByDomainID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADSDOURemoveByDomainIDRDN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADSDOURemoveByGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADSDOUReplaceSubsetByDomainID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADSDOUSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADSDOUTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADSDOUUpdateBatchByDomainIDRDN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADSDOUUpdateByDomainIDRDN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADUserAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADUserAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADUserGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADUserGetAllByDomainID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADUserGetByDomainIDRDN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADUserGetByGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADUserPutByDomainIDRDN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADUserRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADUserRemoveAllByDomainID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADUserRemoveByDomainIDRDN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADUserRemoveByGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADUserReplaceSubsetByDomainID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADUserSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADUserTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADUserUpdateBatchByDomainIDRDN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ADUserUpdateByDomainIDRDN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ArchitectureBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ArchitectureGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ArchitectureGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ArchitectureGetByName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('AUCountDaysG', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('AUCountMdG', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('AUSessions', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('AUSessionsOnComp', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('AUSessionsSummary', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('AUSummary', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('Auto_Config_Complete', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('BindToComputerAndUser', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('CachePackageInsert', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('CachePackageSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('CachePackageSync', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ClearNetworkDevices', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComplianceBulletinAndComputerDetails', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComplianceByBulletinComputerList', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComplianceByBulletinSummaryList', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComplianceByComputerBulletinList', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComplianceByComputerSummaryList', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComplianceComputerAndBulletinList', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('CompUsage', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerGetAllByCN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerGetAllByDomainID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerGetAllByGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerGetAllByOUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerGetByOUIDCN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerPutByOUIDCN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerRemoveAllByCN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerRemoveAllByGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerRemoveAllByOUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerRemoveByOUIDCN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerReplaceSubsetByCN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerReplaceSubsetByGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerReplaceSubsetByOUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerUpdateBatchByOUIDCN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerUpdateByOUIDCN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerUpdateOperatingSystemBound', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerUsageAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerUsageAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerUsageGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerUsageGetAllByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerUsageGetByComputerIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerUsagePutByComputerIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerUsageRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerUsageRemoveAllByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerUsageRemoveByComputerIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerUsageReplaceSubsetByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerUsageSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerUsageTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerUsageUpdateBatchByComputerIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ComputerUsageUpdateByComputerIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('Config_Complete', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('Config_Start', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('CopyPermission', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DatabaseConfigurationAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DatabaseConfigurationAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DatabaseConfigurationGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DatabaseConfigurationGetByProperty', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DatabaseConfigurationPutByProperty', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DatabaseConfigurationRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DatabaseConfigurationRemoveByProperty', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DatabaseConfigurationSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DatabaseConfigurationTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DatabaseConfigurationUpdateBatchByProperty', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DatabaseConfigurationUpdateByProperty', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DBMaintenance', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DeleteAllocation', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DeleteComputer', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DeleteLicensePurchase', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DeleteOrganization', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DeleteUser', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DepLoc_Delete', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistGroup_Create', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistGroup_Delete', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistGroup_Rename', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistGroupMembership_Create', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistGroupMembership_Delete', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributedPackage_Complete', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributedPackage_Start', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributedPackageAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributedPackageAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributedPackageCountByServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributedPackageGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributedPackageGetAllByConfirmedVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributedPackageGetAllByRequestedVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributedPackageGetAllByServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributedPackageGetByServerUIDRequestedVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributedPackagePathGetByServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributedPackagePutByServerUIDRequestedVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributedPackageRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributedPackageRemoveAllByConfirmedVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributedPackageRemoveAllByRequestedVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributedPackageRemoveAllByServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributedPackageRemoveByServerUIDRequestedVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributedPackageReplaceSubsetByConfirmedVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributedPackageReplaceSubsetByRequestedVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributedPackageReplaceSubsetByServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributedPackageSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributedPackageTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributedPackageUpdateBatchByServerUIDRequestedVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributedPackageUpdateByServerUIDRequestedVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionDetails', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionGroupAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionGroupAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionGroupGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionGroupGetByGroupName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionGroupGetByGroupUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionGroupMemberAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionGroupMemberAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionGroupMemberGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionGroupMemberGetAllByGroupUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionGroupMemberGetByGroupUIDMemberID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionGroupMemberPutByGroupUIDMemberID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionGroupMemberRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionGroupMemberRemoveAllByGroupUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionGroupMemberRemoveByGroupUIDMemberID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionGroupMemberReplaceSubsetByGroupUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionGroupMemberSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionGroupMemberTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionGroupMemberUpdateBatchByGroupUIDMemberID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionGroupMemberUpdateByGroupUIDMemberID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionGroupPutByGroupName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionGroupRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionGroupRemoveByGroupName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionGroupRemoveByGroupUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionGroupSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionGroupTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionGroupUpdateBatchByGroupName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionGroupUpdateByGroupName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerAdministrationAccountAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerAdministrationAccountAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerAdministrationAccountGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerAdministrationAccountGetAllByAccountID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerAdministrationAccountGetAllByServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerAdministrationAccountGetByServerUIDAccountID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerAdministrationAccountRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerAdministrationAccountRemoveAllByAccountID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerAdministrationAccountRemoveAllByServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerAdministrationAccountRemoveByServerUIDAccountID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerAdministrationAccountReplaceSubsetByAccountID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerAdministrationAccountReplaceSubsetByServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerAdministrationAccountSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerAdministrationAccountTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerGetByServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerPutByServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerRemoveByServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerTypeGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerTypeGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerTypeGetByName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerUpdateBatchByServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerUpdateByServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerUpdateDNSNameByServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerUpdatePrimaryParentUIDByServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionServerUpdateServerNameByServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionSummary', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DistributionSummaryList', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DomainComputerPopulate', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DomainCreate', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DomainGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DomainGetByDN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DomainGetByDNReverse', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DomainGetByOrganizationID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DomainOrganizationPopulate', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DomainRemove', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('DomainUserPopulate', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('EmptyPolicyUsers', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('FileNameMapAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('FileNameMapAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('FileNameMapGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('FileNameMapGetAllByMediaID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('FileNameMapGetByMediaIDSourceFile', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('FileNameMapPutByMediaIDSourceFile', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('FileNameMapRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('FileNameMapRemoveAllByMediaID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('FileNameMapRemoveByMediaIDSourceFile', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('FileNameMapReplaceSubsetByMediaID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('FileNameMapSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('FileNameMapTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('FileNameMapUpdateBatchByMediaIDSourceFile', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('FileNameMapUpdateByMediaIDSourceFile', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('FindServerOrLoc', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('FixOUReferences', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareClassAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareClassAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareClassBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareClassGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareClassGetAllBySuperClassID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareClassGetAllBySuperClassIDID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareClassGetByClass', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareClassGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareClassPutByClass', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareClassRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareClassRemoveAllBySuperClassID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareClassRemoveAllBySuperClassIDID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareClassRemoveByClass', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareClassRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareClassReplaceSubsetBySuperClassID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareClassReplaceSubsetBySuperClassIDID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareClassSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareClassTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareClassUpdateBatchByClass', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareClassUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareClassUpdateByClass', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareClassUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareObjectAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareObjectAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareObjectBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareObjectGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareObjectGetAllByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareObjectGetAllByComputerIDHardwareName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareObjectGetAllByComputerOUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareObjectGetAllByComputerOUIDHardwareClassID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareObjectGetByComputerIDHardwareNameOccurrence', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareObjectGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareObjectPutByComputerIDHardwareNameOccurrence', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareObjectRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareObjectRemoveAllByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareObjectRemoveAllByComputerIDHardwareName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareObjectRemoveAllByComputerOUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareObjectRemoveAllByComputerOUIDHardwareClassID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareObjectRemoveByComputerIDHardwareNameOccurrence', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareObjectRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareObjectReplaceSubsetByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareObjectReplaceSubsetByComputerIDHardwareName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareObjectReplaceSubsetByComputerOUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareObjectReplaceSubsetByComputerOUIDHardwareClassID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareObjectSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareObjectTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareObjectUpdateBatchByComputerIDHardwareNameOccurrence', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareObjectUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareObjectUpdateByComputerIDHardwareNameOccurrence', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareObjectUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwarePropertyAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwarePropertyAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwarePropertyBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwarePropertyDeleteUnused', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwarePropertyGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwarePropertyGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwarePropertyGetByProperty', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwarePropertyRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwarePropertyRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwarePropertyRemoveByProperty', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwarePropertySchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwarePropertyTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwarePropertyUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwarePropertyUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareValueAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareValueAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareValueGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareValueGetAllByHardwareObjectID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareValueGetByHardwareObjectIDHardwarePropertyID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareValuePutByHardwareObjectIDHardwarePropertyID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareValueRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareValueRemoveAllByHardwareObjectID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareValueRemoveByHardwareObjectIDHardwarePropertyID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareValueReplaceSubsetByHardwareObjectID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareValueSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareValueTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareValueUpdateBatchByHardwareObjectIDHardwarePropertyID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HardwareValueUpdateByHardwareObjectIDHardwarePropertyID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HPUX_FileNameMapGetDestFileBySourceFile', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HPUX_FileNameMapGetSourceFileByDestFile', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HPUX_MediaGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HPUX_MediaGetIDbyTitle', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HPUX_MediaGetPath', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HPUX_MediaGetTitleByPackage', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HPUX_MediaInsert', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HPUX_MediaPackageDependenciesGet', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HPUX_MediaPackageGet', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HPUX_MediaPackageUpdate', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HPUX_MediaPackageVersionGet', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HPUX_MediaProvidesGet', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HPUX_MediaProvidesInsert', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HPUX_MediaRequiresGet', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HPUX_MediaRequiresInsert', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HPUX_MediaTypeInsert', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HPUX_PackageDependenciesGet', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HPUX_PackageExists', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HPUX_PackageGet', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HPUX_PackagePathExistGet', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HPUX_PackagePathGetMedia', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HPUX_PackagePathGetOnlyPackages', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HPUX_PackageProvidesGet', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HPUX_PackageRequiresGet', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HPUX_PackageUpdate', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HPUX_ProvidesInsert', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('HPUX_RequiresInsert', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationAddBound', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationGetAllByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationGetAllByComputerIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationGetAllByOrganizationID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationGetAllByOrganizationIDComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationGetAllByOrganizationIDComputerIDPackageVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationGetAllByOrganizationIDComputerIDPackageVersionIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationGetAllByOrganizationIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationGetAllByPackageVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationGetAllByPackageVersionIDOrganizationID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationGetAllByPackageVersionIDOrganizationIDComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationGetByComputerIDUserIDPackageVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationHistoryAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationHistoryAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationHistoryDeleteOld', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationHistoryGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationHistoryGetAllByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationHistoryGetAllByComputerIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationHistoryGetAllByComputerIDUserIDPackageVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationHistoryGetByComputerIDUserIDPackageVersionIDReported', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationHistoryPutByComputerIDUserIDPackageVersionIDReported', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationHistoryRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationHistoryRemoveAllByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationHistoryRemoveAllByComputerIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationHistoryRemoveAllByComputerIDUserIDPackageVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationHistoryRemoveByComputerIDUserIDPackageVersionIDReported', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationHistoryReplaceSubsetByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationHistoryReplaceSubsetByComputerIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationHistoryReplaceSubsetByComputerIDUserIDPackageVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationHistorySchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationHistoryTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationHistoryUpdateBatchByComputerIDUserIDPackageVersionIDReported', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationHistoryUpdateByComputerIDUserIDPackageVersionIDReported', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationPutByComputerIDUserIDPackageVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationRemoveAllByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationRemoveAllByComputerIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationRemoveAllByOrganizationID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationRemoveAllByOrganizationIDComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationRemoveAllByOrganizationIDComputerIDPackageVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationRemoveAllByOrganizationIDComputerIDPackageVersionIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationRemoveAllByOrganizationIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationRemoveAllByPackageVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationRemoveAllByPackageVersionIDOrganizationID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationRemoveAllByPackageVersionIDOrganizationIDComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationRemoveByComputerIDUserIDPackageVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationReplaceSubsetByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationReplaceSubsetByComputerIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationReplaceSubsetByOrganizationID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationReplaceSubsetByOrganizationIDComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationReplaceSubsetByOrganizationIDComputerIDPackageVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationReplaceSubsetByOrganizationIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationReplaceSubsetByPackageVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationReplaceSubsetByPackageVersionIDOrganizationID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationReplaceSubsetByPackageVersionIDOrganizationIDComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationUpdateBatchByComputerIDUserIDPackageVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InstallationUpdateByComputerIDUserIDPackageVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InventoryReportAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InventoryReportAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InventoryReportGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InventoryReportGetAllByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InventoryReportGetByComputerIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InventoryReportPutByComputerIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InventoryReportRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InventoryReportRemoveAllByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InventoryReportRemoveByComputerIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InventoryReportReplaceSubsetByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InventoryReportSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InventoryReportTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InventoryReportUpdateBatchByComputerIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('InventoryReportUpdateByComputerIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('JobAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('JobAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('JobGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('JobGetAllByTaskID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('JobGetByTaskIDServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('JobGetByUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('JobPutByTaskIDServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('JobRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('JobRemoveAllByTaskID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('JobRemoveByTaskIDServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('JobRemoveByUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('JobReplaceSubsetByTaskID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('JobSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('JobTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('JobUpdateBatchByTaskIDServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('JobUpdateByTaskIDServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LanguageAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LanguageAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LanguageGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LanguageGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LanguageRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LanguageRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LanguageSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LanguageTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LanguageUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LanguageUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseAllocationAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseAllocationAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseAllocationGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseAllocationGetAllByOrganizationID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseAllocationGetAllByOrganizationIDSoftwareProductID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseAllocationGetAllBySoftwareProductID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseAllocationGetAllBySoftwareProductIDOrganizationID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseAllocationGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseAllocationRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseAllocationRemoveAllByOrganizationID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseAllocationRemoveAllByOrganizationIDSoftwareProductID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseAllocationRemoveAllBySoftwareProductID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseAllocationRemoveAllBySoftwareProductIDOrganizationID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseAllocationRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseAllocationSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseAllocationTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseAllocationUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseAllocationUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseInventoryDetails', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseModelAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseModelAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseModelBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseModelGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseModelGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseModelGetByName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseModelRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseModelRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseModelRemoveByName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseModelSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseModelTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseModelUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicenseModelUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicensePurchaseAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicensePurchaseAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicensePurchaseDetails', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicensePurchaseGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicensePurchaseGetAllBySoftwareProductID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicensePurchaseGetAllBySoftwareProductIDOrganizationID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicensePurchaseGetAllBySoftwareProductIDOrganizationIDResellerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicensePurchaseGetAllBySoftwareProductIDOrganizationIDResellerIDPurchased', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicensePurchaseGetBySoftwareProductIDOrganizationIDResellerIDPurchasedOrderNumber', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicensePurchasePutBySoftwareProductIDOrganizationIDResellerIDPurchasedOrderNumber', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicensePurchaseRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicensePurchaseRemoveAllBySoftwareProductID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicensePurchaseRemoveAllBySoftwareProductIDOrganizationID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicensePurchaseRemoveAllBySoftwareProductIDOrganizationIDResellerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicensePurchaseRemoveAllBySoftwareProductIDOrganizationIDResellerIDPurchased', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicensePurchaseRemoveBySoftwareProductIDOrganizationIDResellerIDPurchasedOrderNumber', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicensePurchaseReplaceSubsetBySoftwareProductID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicensePurchaseReplaceSubsetBySoftwareProductIDOrganizationID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicensePurchaseReplaceSubsetBySoftwareProductIDOrganizationIDResellerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicensePurchaseReplaceSubsetBySoftwareProductIDOrganizationIDResellerIDPurchased', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicensePurchaseSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicensePurchaseSummaryList', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicensePurchaseTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicensePurchaseUpdateBatchBySoftwareProductIDOrganizationIDResellerIDPurchasedOrderNumber', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LicensePurchaseUpdateBySoftwareProductIDOrganizationIDResellerIDPurchasedOrderNumber', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('LinkNetworkDevice', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ListDomains', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ManagedDeviceHWSummary', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ManagedDeviceInstallDetails', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ManagedDeviceSummaryList', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaContainsPackageVersionAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaContainsPackageVersionAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaContainsPackageVersionGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaContainsPackageVersionGetAllByMediaID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaContainsPackageVersionGetAllByPackageVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaContainsPackageVersionGetByMediaIDPackageVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaContainsPackageVersionRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaContainsPackageVersionRemoveAllByMediaID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaContainsPackageVersionRemoveAllByPackageVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaContainsPackageVersionRemoveByMediaIDPackageVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaContainsPackageVersionReplaceSubsetByMediaID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaContainsPackageVersionReplaceSubsetByPackageVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaContainsPackageVersionSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaContainsPackageVersionTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaDeleteUnused', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaGetAllByTypeID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaGetByTitle', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaInsert', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaPackageDependenciesGet', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaPackageGet', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaPackageVersionGet', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaProvidesGet', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaProvidesInsert', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaPutByTitle', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaRemoveAllByTypeID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaRemoveByTitle', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaReplaceSubsetByTypeID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaRequiresGet', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaRequiresInsert', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaRPMPackageUpdate', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaTypeGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaTypeGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaTypeInsert', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaUpdateBatchByTitle', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MediaUpdateByTitle', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsAddWakeOnLANJob', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsAddWakeOnLANStatus', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsAddWakeOnLANTask', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsAgedManagedDevices', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsAllocationDetails', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsAllSoftwareProductSummary', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsAllSoftwareVersions', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsContainedSoftware', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsDistParentName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsDLDistributionDetails', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsDLDistributionSummary', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsDLDistributionSummaryList', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsDSDistributionConfig', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsDSDistributionDetails', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsDSDistributionSummary', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsDSDistributionSummaryList', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsEditAllocations', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsGetWakeOnLANHostInfo', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsHWClassesInventorySummaryList', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsHWClassManagedDevicesSummaryList', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsListModels', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsListPublishers', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsListResellers', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsListTracking', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsManagedDeviceHWClassDetails', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsManagedDeviceHWClassesSummaryList', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsManagedDevicesInventorySummaryList', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsManagedDeviceSWInventoryDetails', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsOSBreakdown', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsOUAllocations', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsOUDNtoOUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsOUsSoftwareProductAllocation', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsPkgDistributionDetails', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsPkgsDistributionSummary', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsPkgsDistributionSummaryList', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsRemoveWakeOnLANTask', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsROAllSoftwareProductSummary', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsSoftwareProductAllocationBreachSummaryList', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsSoftwareProductAllocationSummary', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsSoftwareProductAllocationSummaryList', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsSoftwareProductUsageDetails', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsSWInventoryDetails', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsSWInventoryList', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsSWInventorySummaryList', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsSWVersionsInventorySummaryList', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsUpdateWakeOnLANJob', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsUpdateWakeOnLANStatus', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsUsersSWInventorySummaryList', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('mgsUserSWInventoryDetails', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MoveComputerToNewOU', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('MoveUserToNewOU', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceDiscoveredByAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceDiscoveredByAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceDiscoveredByGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceDiscoveredByGetAllByDeviceID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceDiscoveredByGetAllByServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceDiscoveredByGetByDeviceIDServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceDiscoveredByPutByDeviceIDServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceDiscoveredByRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceDiscoveredByRemoveAllByDeviceID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceDiscoveredByRemoveAllByServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceDiscoveredByRemoveByDeviceIDServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceDiscoveredByReplaceSubsetByDeviceID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceDiscoveredByReplaceSubsetByServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceDiscoveredBySchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceDiscoveredByTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceDiscoveredByUpdateBatchByDeviceIDServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceDiscoveredByUpdateByDeviceIDServerUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceGetAllByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceGetAllByDeviceName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceGetAllByDuplicateID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceGetAllByIPAddress', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceGetAllByLastDataSourceType', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceGetAllByLastDataSourceTypeLastDataSourceName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceGetAllByNTDomainName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceGetAllByPhysicalAddress', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceGetTargetedByOU', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceGetTargetedByPolicy', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceRemoveAllByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceRemoveAllByDeviceName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceRemoveAllByDuplicateID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceRemoveAllByIPAddress', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceRemoveAllByLastDataSourceType', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceRemoveAllByLastDataSourceTypeLastDataSourceName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceRemoveAllByNTDomainName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceRemoveAllByPhysicalAddress', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NetworkDeviceUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('NewEmptyDistServer', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OperatingSystemAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OperatingSystemAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OperatingSystemBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OperatingSystemCategoryTest', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OperatingSystemGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OperatingSystemGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OperatingSystemRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OperatingSystemRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OperatingSystemSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OperatingSystemTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OperatingSystemUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OperatingSystemUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OrganizationAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OrganizationAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OrganizationBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OrganizationCreate', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OrganizationDNCreate', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OrganizationGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OrganizationGetAllByDomainID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OrganizationGetAllByGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OrganizationGetByDomainIDRDN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OrganizationGetByDomainIDRDNReverse', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OrganizationGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OrganizationPutByDomainIDRDN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OrganizationRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OrganizationRemoveAllByDomainID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OrganizationRemoveAllByGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OrganizationRemoveByDomainIDRDN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OrganizationRemoveByDomainIDRDNReverse', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OrganizationRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OrganizationReplaceSubsetByDomainID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OrganizationReplaceSubsetByGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OrganizationSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OrganizationTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OrganizationUpdateBatchByDomainIDRDN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OrganizationUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OrganizationUpdateByDomainIDRDN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OrganizationUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('OUDN_to_RDNandDomainDN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageDependenciesGet', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageDistributionSummary', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageDistributionSummaryList', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageFamilyAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageFamilyAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageFamilyBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageFamilyGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageFamilyGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageFamilyGetByPackageName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageFamilyRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageFamilyRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageFamilyRemoveByPackageName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageFamilySchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageFamilyTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageFamilyUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageFamilyUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackagePathAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackagePathAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackagePathBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackagePathDeleteUnused', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackagePathExistGet', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackagePathGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackagePathGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackagePathGetByPackageFullName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackagePathGetOnlyPackages', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackagePathPutByPackageFullName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackagePathRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackagePathRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackagePathRemoveByPackageFullName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackagePathSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackagePathTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackagePathUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackagePathUpdateBatchByPackageFullName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackagePathUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackagePathUpdateByPackageFullName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageProvidesAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageProvidesAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageProvidesGet', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageProvidesGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageProvidesGetAllByPackageFamilyID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageProvidesGetAllByPackageFamilyIDVersion', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageProvidesGetAllByPackageFamilyIDVersionPackageVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageProvidesGetAllByPackageVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageProvidesGetAllByPackageVersionIDPackageFamilyID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageProvidesGetByPackageVersionIDPackageFamilyIDVersion', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageProvidesRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageProvidesRemoveAllByPackageFamilyID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageProvidesRemoveAllByPackageFamilyIDVersion', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageProvidesRemoveAllByPackageFamilyIDVersionPackageVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageProvidesRemoveAllByPackageVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageProvidesRemoveAllByPackageVersionIDPackageFamilyID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageProvidesRemoveByPackageVersionIDPackageFamilyIDVersion', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageProvidesReplaceSubsetByPackageFamilyID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageProvidesReplaceSubsetByPackageFamilyIDVersion', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageProvidesReplaceSubsetByPackageVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageProvidesReplaceSubsetByPackageVersionIDPackageFamilyID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageProvidesSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageProvidesTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageRequiresAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageRequiresAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageRequiresGet', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageRequiresGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageRequiresGetAllByPackageVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageRequiresGetAllByPackageVersionIDRequiredType', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageRequiresGetAllByPackageVersionIDRequiredTypeRequiredObject', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageRequiresGetByPackageVersionIDRequiredTypeRequiredObjectMatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageRequiresPutByPackageVersionIDRequiredTypeRequiredObjectMatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageRequiresRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageRequiresRemoveAllByPackageVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageRequiresRemoveAllByPackageVersionIDRequiredType', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageRequiresRemoveAllByPackageVersionIDRequiredTypeRequiredObject', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageRequiresRemoveByPackageVersionIDRequiredTypeRequiredObjectMatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageRequiresReplaceSubsetByPackageVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageRequiresReplaceSubsetByPackageVersionIDRequiredType', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageRequiresReplaceSubsetByPackageVersionIDRequiredTypeRequiredObject', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageRequiresSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageRequiresTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageRequiresUpdateBatchByPackageVersionIDRequiredTypeRequiredObjectMatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageRequiresUpdateByPackageVersionIDRequiredTypeRequiredObjectMatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionAddBound', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionBindBound', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionGetAllByPackagePathID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionGetAllByPackagePathIDVersion', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionGetAllByPackagePathIDVersionUpdate', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionGetByPackagePathIDVersionUpdateArchitectureID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionGetLatestVersionAndFamilyByPackageFullName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionList', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionPutByPackagePathIDVersionUpdateArchitectureID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionRemoveAllByPackagePathID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionRemoveAllByPackagePathIDVersion', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionRemoveAllByPackagePathIDVersionUpdate', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionRemoveByPackagePathIDVersionUpdateArchitectureID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionRemoveWarehouse', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionReplaceSubsetByPackagePathID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionReplaceSubsetByPackagePathIDVersion', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionReplaceSubsetByPackagePathIDVersionUpdate', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionsByPackageName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionUpdateBatchByPackagePathIDVersionUpdateArchitectureID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionUpdateByPackagePathIDVersionUpdateArchitectureID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionUpdateMD5', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionUpdateWarehouse', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionUpdateWarehouseWithCategoryUpdateArchitecture', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PatchesDistributionSummaryList', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PatchPackageVersionList', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PerLicenseSummary', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PerOULicAllocDetails', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesGetAllByDomainID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesGetAllByGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesGetAllByGUIDTargetOUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesGetAllByTargetOUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesGetAllByTargetOUIDTargetTypeID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesGetAllByTargetOUIDTargetTypeIDTargetID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesGetByTargetOUIDTargetTypeIDTargetIDGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesPutByTargetOUIDTargetTypeIDTargetIDGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesRemoveAllByDomainID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesRemoveAllByGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesRemoveAllByGUIDTargetOUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesRemoveAllByTargetOUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesRemoveAllByTargetOUIDTargetTypeID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesRemoveAllByTargetOUIDTargetTypeIDTargetID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesRemoveByTargetOUIDTargetTypeIDTargetIDGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesReplaceSubsetByDomainID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesReplaceSubsetByGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesReplaceSubsetByGUIDTargetOUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesReplaceSubsetByParentOrganization', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesReplaceSubsetByPolicyDomainID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesReplaceSubsetByTargetOUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesReplaceSubsetByTargetOUIDTargetTypeID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesReplaceSubsetByTargetOUIDTargetTypeIDTargetID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesUpdateBatchByTargetOUIDTargetTypeIDTargetIDGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyAppliesUpdateByTargetOUIDTargetTypeIDTargetIDGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyClearDuplicates', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyDistributeCount', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyDistributeQuery', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyGetAllByDomainID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyGetByGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyInsertNew6', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyInstallationUpdate', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyInstallationUpdate6', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyPutByGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyRemoveAllByDomainID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyRemoveByGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyRemoveOld', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyRemoveOld6', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyReplaceSubsetByDomainID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicySchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyUpdateBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyUpdateBatch6', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyUpdateBatchByGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyUpdateByGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyUpdateChanged6', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyUpdateDiagnostics6', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PolicyUpdatePolicies6', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PopulateComputerGUIDs', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PopulateCustomUninstall', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PopulateMissingOUs', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PopulateNetworkDevices', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PopulateOrganizationGUIDs', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PopulateUninstall', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('PopulateUserGUIDs', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ProductContainsSoftwareAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ProductContainsSoftwareAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ProductContainsSoftwareGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ProductContainsSoftwareGetAllBySoftwareProductID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ProductContainsSoftwareGetAllBySoftwareVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ProductContainsSoftwareGetBySoftwareVersionIDSoftwareProductID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ProductContainsSoftwareRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ProductContainsSoftwareRemoveAllBySoftwareProductID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ProductContainsSoftwareRemoveAllBySoftwareVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ProductContainsSoftwareRemoveBySoftwareVersionIDSoftwareProductID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ProductContainsSoftwareReplaceSubsetBySoftwareProductID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ProductContainsSoftwareReplaceSubsetBySoftwareVersionID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ProductContainsSoftwareSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ProductContainsSoftwareTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ProvidesInsert', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ReconcileComputers', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ReconcileDomain', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ReconcileDomainNow', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ReconcileOrganizations', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ReconcileUsers', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('RemoteExec_Complete', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('RemovePackage_Complete', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('RemovePackage_Start', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('RenameComputer', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('RenameOrganization', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('RenameUser', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('RequiresInsert', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('Resync_Clear', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('Resync_State', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('ReverseDN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('RPMPackageExists', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('RPMPackageGet', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('RPMPackageUpdate', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedProductAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedProductAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedProductBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedProductGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedProductGetAllByPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedProductGetAllByProductID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedProductGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedProductGetByProductIDPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedProductPutByProductIDPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedProductRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedProductRemoveAllByPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedProductRemoveAllByProductID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedProductRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedProductRemoveByProductIDPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedProductReplaceSubsetByPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedProductReplaceSubsetByProductID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedProductSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedProductTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedProductUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedProductUpdateBatchByProductIDPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedProductUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedProductUpdateByProductIDPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedServicePackAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedServicePackAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedServicePackBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedServicePackGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedServicePackGetAllByAffectedProductID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedServicePackGetByAffectedProductIDServicePackID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedServicePackGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedServicePackRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedServicePackRemoveAllByAffectedProductID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedServicePackRemoveByAffectedProductIDServicePackID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedServicePackRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedServicePackReplaceSubsetByAffectedProductID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedServicePackSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedServicePackTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedServicePackUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AffectedServicePackUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AvailableSPAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AvailableSPAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AvailableSPGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AvailableSPGetByServicePackID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AvailableSPPutByServicePackID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AvailableSPRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AvailableSPRemoveByServicePackID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AvailableSPSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AvailableSPTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AvailableSPUpdateBatchByServicePackID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_AvailableSPUpdateByServicePackID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_BulletinAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_BulletinAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_BulletinCommentAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_BulletinCommentAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_BulletinCommentBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_BulletinCommentGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_BulletinCommentGetAllByCommentID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_BulletinCommentGetByCommentIDBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_BulletinCommentGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_BulletinCommentRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_BulletinCommentRemoveAllByCommentID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_BulletinCommentRemoveByCommentIDBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_BulletinCommentRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_BulletinCommentReplaceSubsetByCommentID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_BulletinCommentSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_BulletinCommentTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_BulletinCommentUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_BulletinCommentUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_BulletinGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_BulletinGetByBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_BulletinPutByBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_BulletinRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_BulletinRemoveByBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_BulletinSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_BulletinTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_BulletinUpdateBatchByBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_BulletinUpdateByBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_CommandAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_CommandAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_CommandGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_CommandGetByCommandID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_CommandPutByCommandID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_CommandRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_CommandRemoveByCommandID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_CommandSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_CommandTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_CommandUpdateBatchByCommandID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_CommandUpdateByCommandID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_CommentAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_CommentAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_CommentGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_CommentGetByCommentID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_CommentPutByCommentID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_CommentRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_CommentRemoveByCommentID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_CommentSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_CommentTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_CommentUpdateBatchByCommentID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_CommentUpdateByCommentID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileChangeAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileChangeAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileChangeGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileChangeGetByFileChangeID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileChangePutByFileChangeID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileChangeRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileChangeRemoveByFileChangeID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileChangeSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileChangeTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileChangeUpdateBatchByFileChangeID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileChangeUpdateByFileChangeID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileChgAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileChgAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileChgBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileChgGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileChgGetAllByPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileChgGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileChgGetByPatchIDFileChangeID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileChgRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileChgRemoveAllByPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileChgRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileChgRemoveByPatchIDFileChangeID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileChgReplaceSubsetByPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileChgSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileChgTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileChgUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileChgUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileGetByFileID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FilePutByFileID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileRemoveByFileID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileUpdateBatchByFileID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_FileUpdateByFileID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_LocationAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_LocationAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_LocationGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_LocationGetByLocationID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_LocationPutByLocationID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_LocationRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_LocationRemoveByLocationID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_LocationSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_LocationTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_LocationUpdateBatchByLocationID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_LocationUpdateByLocationID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchCommentAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchCommentAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchCommentBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchCommentGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchCommentGetAllByCommentID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchCommentGetByCommentIDPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchCommentGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchCommentRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchCommentRemoveAllByCommentID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchCommentRemoveByCommentIDPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchCommentRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchCommentReplaceSubsetByCommentID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchCommentSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchCommentTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchCommentUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchCommentUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchGetAllByBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchGetAllByPatchName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchGetAllByPatchNameBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchGetAllByPatchNameBulletinIDPatchLocationID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchGetByPatchNameBulletinIDPatchLocationIDSQNumber', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchGetBySecurityPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchPutBySecurityPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchRemoveAllByBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchRemoveAllByPatchName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchRemoveAllByPatchNameBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchRemoveAllByPatchNameBulletinIDPatchLocationID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchRemoveByPatchNameBulletinIDPatchLocationIDSQNumber', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchRemoveBySecurityPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchReplaceSubsetByBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchReplaceSubsetByPatchName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchReplaceSubsetByPatchNameBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchReplaceSubsetByPatchNameBulletinIDPatchLocationID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchUpdateBatchBySecurityPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_PatchUpdateBySecurityPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductFamilyAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductFamilyAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductFamilyGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductFamilyGetByProductFamilyID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductFamilyPutByProductFamilyID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductFamilyRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductFamilyRemoveByProductFamilyID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductFamilySchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductFamilyTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductFamilyUpdateBatchByProductFamilyID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductFamilyUpdateByProductFamilyID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductGetByProductID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductProductFamilyAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductProductFamilyAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductProductFamilyBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductProductFamilyGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductProductFamilyGetAllByProductID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductProductFamilyGetByProductIDProductFamilyID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductProductFamilyRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductProductFamilyRemoveAllByProductID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductProductFamilyRemoveByProductIDProductFamilyID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductProductFamilyReplaceSubsetByProductID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductProductFamilySchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductProductFamilyTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductPutByProductID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductRemoveByProductID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductUpdateBatchByProductID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ProductUpdateByProductID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_QNumberAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_QNumberAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_QNumberGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_QNumberGetByqNumber', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_QNumberPutByqNumber', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_QNumberRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_QNumberRemoveByqNumber', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_QNumberSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_QNumberTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_QNumberUpdateBatchByqNumber', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_QNumberUpdateByqNumber', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegChangeAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegChangeAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegChangeGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegChangeGetByRegChangeID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegChangePutByRegChangeID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegChangeRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegChangeRemoveByRegChangeID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegChangeSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegChangeTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegChangeUpdateBatchByRegChangeID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegChangeUpdateByRegChangeID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegChgAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegChgAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegChgBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegChgGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegChgGetAllByPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegChgGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegChgGetByPatchIDRegChangeID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegChgRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegChgRemoveAllByPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegChgRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegChgRemoveByPatchIDRegChangeID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegChgReplaceSubsetByPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegChgSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegChgTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegChgUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegChgUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegKeyAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegKeyAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegKeyGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegKeyGetByRegKeyID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegKeyPutByRegKeyID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegKeyRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegKeyRemoveByRegKeyID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegKeySchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegKeyTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegKeyUpdateBatchByRegKeyID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_RegKeyUpdateByRegKeyID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ServicePackAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ServicePackAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ServicePackGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ServicePackGetByServicePackID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ServicePackPutByServicePackID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ServicePackRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ServicePackRemoveByServicePackID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ServicePackSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ServicePackTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ServicePackUpdateBatchByServicePackID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_ServicePackUpdateByServicePackID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SeverityAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SeverityAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SeverityGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SeverityGetBySeverityID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SeverityPutBySeverityID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SeverityRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SeverityRemoveBySeverityID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SeveritySchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SeverityTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SeverityUpdateBatchBySeverityID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SeverityUpdateBySeverityID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededByAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededByAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededByGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededByGetBySBID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededByPutBySBID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededByRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededByRemoveBySBID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededBySchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededByTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededByUpdateBatchBySBID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededByUpdateBySBID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededPatchAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededPatchAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededPatchBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededPatchGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededPatchGetAllByPatchName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededPatchGetAllByPatchNameBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededPatchGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededPatchGetByPatchNameBulletinIDSupercededByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededPatchRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededPatchRemoveAllByPatchName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededPatchRemoveAllByPatchNameBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededPatchRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededPatchRemoveByPatchNameBulletinIDSupercededByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededPatchReplaceSubsetByPatchName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededPatchReplaceSubsetByPatchNameBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededPatchSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededPatchTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededPatchUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SupercededPatchUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SUSMappingAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SUSMappingAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SUSMappingGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SUSMappingGetAllBySUSPatchName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SUSMappingGetBySUSPatchNamePatchName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SUSMappingRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SUSMappingRemoveAllBySUSPatchName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SUSMappingRemoveBySUSPatchNamePatchName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SUSMappingReplaceSubsetBySUSPatchName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SUSMappingSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecPatch_SUSMappingTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityAnalysisComputerList', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityAnalysisReportAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityAnalysisReportAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityAnalysisReportGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityAnalysisReportGetAllByDataSourceDate', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityAnalysisReportGetByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityAnalysisReportPutByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityAnalysisReportRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityAnalysisReportRemoveAllByDataSourceDate', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityAnalysisReportRemoveByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityAnalysisReportReplaceSubsetByDataSourceDate', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityAnalysisReportSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityAnalysisReportTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityAnalysisReportUpdateBatchByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityAnalysisReportUpdateByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinGetAffectedProducts', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinGetAlerts', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinGetAllDetailed', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinGetAllUIStateCount', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinGetByBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinGetCountByUIState', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinGetDependenciesBySecurityBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinGetInProgress', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinGetInProgressProductGroups', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinGetInProgressProducts', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinGetInProgressUserStates', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinGetNewOrUpdated', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinGetNewOrUpdatedProductGroups', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinGetNewOrUpdatedProducts', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinGetNewOrUpdatedUserStates', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinGetPackaged', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinGetPatches', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinGetReleased', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinGetReleasedProductGroups', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinGetReleasedProducts', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinGetReleasedUserStates', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinGetSuppressed', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinGetSuppressedProductGroups', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinGetSuppressedProducts', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinGetSuppressedUserStates', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinGetTargeted', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinGetTargetedPatches', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinHide', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinList', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinPutByBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinRemoveByBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinRequiresAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinRequiresAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinRequiresGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinRequiresGetAllBySecurityBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinRequiresGetAllBySecurityBulletinIDRequiredBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinRequiresGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinRequiresRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinRequiresRemoveAllBySecurityBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinRequiresRemoveAllBySecurityBulletinIDRequiredBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinRequiresRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinRequiresSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinRequiresTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinRequiresUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinRequiresUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinToUserStateAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinToUserStateAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinToUserStateGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinToUserStateGetAllBySecurityBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinToUserStateGetBySecurityBulletinIDUserStateID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinToUserStatePutBySecurityBulletinIDUserStateID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinToUserStateRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinToUserStateRemoveAllBySecurityBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinToUserStateRemoveBySecurityBulletinIDUserStateID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinToUserStateReplaceSubsetBySecurityBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinToUserStateSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinToUserStateTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinToUserStateUpdateBatchBySecurityBulletinIDUserStateID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinToUserStateUpdateBySecurityBulletinIDUserStateID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinUpdateBatchByBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinUpdateByBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinUpdateEmergencyByBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinUpdateHideAllSuperceded', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinUpdateHideByBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityBulletinUpdateUnhideByBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchAnalysisAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchAnalysisAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchAnalysisGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchAnalysisGetAllByBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchAnalysisGetAllByBulletinIDComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchAnalysisGetAllByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchAnalysisGetAllByComputerIDBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchAnalysisPutByComputerIDBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchAnalysisRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchAnalysisRemoveAllByBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchAnalysisRemoveAllByBulletinIDComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchAnalysisRemoveAllByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchAnalysisRemoveAllByComputerIDBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchAnalysisReplaceSubsetByBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchAnalysisReplaceSubsetByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchAnalysisSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchAnalysisTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchAnalysisUpdateBatchByComputerIDBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchAnalysisUpdateByComputerIDBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchGetAffectedProducts', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchGetAllByPatchName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchGetAllByPatchNameBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchGetAllByPatchNameBulletinIDDownloadLocation', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchGetByPatchNameBulletinIDDownloadLocationQNumber', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchGetPolicies', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchInstallationDetailComputerExactOU', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchInstallationDetailComputerMatchOU', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchInstallationDetails', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchInstallationNonPolicyComputerExactOU', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchInstallationNonPolicyComputerMatchOU', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchInstallationNotrequired', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchInstallationPending', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchInstallationPendingComputerExactOU', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchInstallationPendingComputerMatchOU', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchInstallationSuccess', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchInstallationSummary', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchInstallationSummaryExactOU', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchInstallationSummaryMatchOU', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchProductGroupAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchProductGroupAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchProductGroupGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchProductGroupGetAllByEnvironment', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchProductGroupGetAllByProduct', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchProductGroupGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchProductGroupRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchProductGroupRemoveAllByEnvironment', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchProductGroupRemoveAllByProduct', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchProductGroupRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchProductGroupSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchProductGroupTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchProductGroupUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchProductGroupUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchProductUninstallValuesAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchProductUninstallValuesAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchProductUninstallValuesGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchProductUninstallValuesGetAllByProduct', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchProductUninstallValuesGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchProductUninstallValuesRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchProductUninstallValuesRemoveAllByProduct', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchProductUninstallValuesRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchProductUninstallValuesSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchProductUninstallValuesTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchProductUninstallValuesUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchProductUninstallValuesUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchPutByPatchNameBulletinIDDownloadLocationQNumber', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchRemoveAllByPatchName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchRemoveAllByPatchNameBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchRemoveAllByPatchNameBulletinIDDownloadLocation', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchRemoveByPatchNameBulletinIDDownloadLocationQNumber', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchReplaceSubsetByPatchName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchReplaceSubsetByPatchNameBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchReplaceSubsetByPatchNameBulletinIDDownloadLocation', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchRequiresAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchRequiresAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchRequiresGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchRequiresGetAllByPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchRequiresGetAllByPatchIDRequiredPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchRequiresGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchRequiresRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchRequiresRemoveAllByPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchRequiresRemoveAllByPatchIDRequiredPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchRequiresRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchRequiresSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchRequiresTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchRequiresUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchRequiresUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchStatusAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchStatusAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchStatusBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchStatusGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchStatusGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchStatusGetByInternalText', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchStatusPutByInternalText', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchStatusRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchStatusRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchStatusRemoveByInternalText', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchStatusSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchStatusTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchStatusUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchStatusUpdateBatchByInternalText', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchStatusUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchStatusUpdateByInternalText', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchSupercededBy', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchSupercedes', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchToPackageVersionAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchToPackageVersionAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchToPackageVersionGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchToPackageVersionGetAllByPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchToPackageVersionGetByPatchIDPackageFullName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchToPackageVersionPutByPatchIDPackageFullName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchToPackageVersionRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchToPackageVersionRemoveAllByPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchToPackageVersionRemoveByPatchIDPackageFullName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchToPackageVersionReplaceSubsetByPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchToPackageVersionSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchToPackageVersionTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchToPackageVersionUpdateBatchByPatchIDPackageFullName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchToPackageVersionUpdateByPatchIDPackageFullName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchUIProductGroupAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchUIProductGroupAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchUIProductGroupGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchUIProductGroupGetAllByGroupName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchUIProductGroupGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchUIProductGroupGetGroupNames', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchUIProductGroupRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchUIProductGroupRemoveAllByGroupName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchUIProductGroupRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchUIProductGroupSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchUIProductGroupTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchUIProductGroupUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchUIProductGroupUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchUninstallValuesAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchUninstallValuesAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchUninstallValuesGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchUninstallValuesGetAllBySecurityPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchUninstallValuesGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchUninstallValuesRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchUninstallValuesRemoveAllBySecurityPatchID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchUninstallValuesRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchUninstallValuesSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchUninstallValuesTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchUninstallValuesUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchUninstallValuesUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchUpdateBatchByPatchNameBulletinIDDownloadLocationQNumber', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityPatchUpdateByPatchNameBulletinIDDownloadLocationQNumber', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateChangeAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateChangeAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateChangeBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateChangeGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateChangeGetAllByBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateChangeGetByBulletinIDDateChanged', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateChangeGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateChangePutByBulletinIDDateChanged', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateChangeRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateChangeRemoveAllByBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateChangeRemoveByBulletinIDDateChanged', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateChangeRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateChangeReplaceSubsetByBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateChangeSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateChangeTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateChangeUpdateBatchByBulletinIDDateChanged', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateChangeUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateChangeUpdateByBulletinIDDateChanged', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateChangeUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateGetIDByDescription', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityStateUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUIStateAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUIStateAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUIStateGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUIStateGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUIStateGetIDByDescription', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUIStateRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUIStateRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUIStateSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUIStateTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUIStateUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUIStateUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUserStateAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUserStateAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUserStateChangeAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUserStateChangeAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUserStateChangeGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUserStateChangeGetAllBySecurityBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUserStateChangeGetAllBySecurityBulletinIDDateChanged', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUserStateChangeGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUserStateChangeRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUserStateChangeRemoveAllBySecurityBulletinID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUserStateChangeRemoveAllBySecurityBulletinIDDateChanged', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUserStateChangeRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUserStateChangeSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUserStateChangeTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUserStateChangeUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUserStateChangeUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUserStateGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUserStateGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUserStateRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUserStateRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUserStateSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUserStateTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUserStateUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SecurityUserStateUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareFileAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareFileAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareFileGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareFileGetAllByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareFileGetAllByComputerIDSoftwareID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareFileGetAllByComputerOUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareFileGetAllByComputerOUIDComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareFileGetAllByComputerOUIDComputerIDSoftwareID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareFileGetByComputerIDSoftwareIDFilename', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareFilePutByComputerIDSoftwareIDFilename', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareFileRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareFileRemoveAllByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareFileRemoveAllByComputerIDSoftwareID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareFileRemoveAllByComputerOUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareFileRemoveAllByComputerOUIDComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareFileRemoveAllByComputerOUIDComputerIDSoftwareID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareFileRemoveByComputerIDSoftwareIDFilename', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareFileReplaceSubsetByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareFileReplaceSubsetByComputerIDSoftwareID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareFileReplaceSubsetByComputerOUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareFileReplaceSubsetByComputerOUIDComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareFileReplaceSubsetByComputerOUIDComputerIDSoftwareID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareFileSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareFileTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareFileUpdateBatchByComputerIDSoftwareIDFilename', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareFileUpdateByComputerIDSoftwareIDFilename', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceGetAllByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceGetAllByComputerIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceGetAllByComputerOUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceGetAllByComputerOUIDComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceGetAllByComputerOUIDComputerIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceGetAllByComputerOUIDComputerIDUserIDSoftwareID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceGetAllBySoftwareID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceGetAllBySoftwareIDComputerOUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceGetAllBySoftwareIDComputerOUIDComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceGetByComputerIDUserIDSoftwareID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceGetBySoftwareIDComputerOUIDComputerIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrencePutByComputerIDUserIDSoftwareID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceRemoveAllByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceRemoveAllByComputerIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceRemoveAllByComputerOUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceRemoveAllByComputerOUIDComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceRemoveAllByComputerOUIDComputerIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceRemoveAllByComputerOUIDComputerIDUserIDSoftwareID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceRemoveAllBySoftwareID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceRemoveAllBySoftwareIDComputerOUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceRemoveAllBySoftwareIDComputerOUIDComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceRemoveByComputerIDUserIDSoftwareID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceRemoveBySoftwareIDComputerOUIDComputerIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceReplaceSubsetByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceReplaceSubsetByComputerIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceReplaceSubsetByComputerOUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceReplaceSubsetByComputerOUIDComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceReplaceSubsetByComputerOUIDComputerIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceReplaceSubsetBySoftwareID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceReplaceSubsetBySoftwareIDComputerOUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceReplaceSubsetBySoftwareIDComputerOUIDComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceUpdateBatchByComputerIDUserIDSoftwareID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareOccurrenceUpdateByComputerIDUserIDSoftwareID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePackageInstallationDetailComputerExactOU', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePackageInstallationDetailComputerMatchOU', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePackageInstallationDetails', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePackageInstallationDetailUserExactOU', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePackageInstallationDetailUserMatchOU', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePackageInstallationNonPolicyComputerExactOU', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePackageInstallationNonPolicyComputerMatchOU', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePackageInstallationNonPolicyUserExactOU', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePackageInstallationNonPolicyUserMatchOU', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePackageInstallationPending', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePackageInstallationPendingComputerExactOU', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePackageInstallationPendingComputerMatchOU', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePackageInstallationPendingUserExactOU', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePackageInstallationPendingUserMatchOU', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePackageInstallationSuccess', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePackageInstallationSummary', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePackageInstallationSummaryExactOU', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePackageInstallationSummaryMatchOU', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareProductAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareProductAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareProductBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareProductGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareProductGetAllByModelID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareProductGetAllByPublisherID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareProductGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareProductGetByProductName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareProductPutByProductName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareProductRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareProductRemoveAllByModelID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareProductRemoveAllByPublisherID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareProductRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareProductRemoveByProductName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareProductReplaceSubsetByModelID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareProductReplaceSubsetByPublisherID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareProductSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareProductTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareProductUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareProductUpdateBatchByProductName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareProductUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareProductUpdateByProductName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePublisherAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePublisherAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePublisherBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePublisherGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePublisherGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePublisherGetByName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePublisherPutByName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePublisherRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePublisherRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePublisherRemoveByName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePublisherSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePublisherTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePublisherUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePublisherUpdateBatchByName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePublisherUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwarePublisherUpdateByName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareResellerAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareResellerAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareResellerBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareResellerGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareResellerGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareResellerGetByName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareResellerPutByName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareResellerRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareResellerRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareResellerRemoveByName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareResellerSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareResellerTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareResellerUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareResellerUpdateBatchByName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareResellerUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareResellerUpdateByName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareUsageDeleteConditional', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareUsageDeleteOld', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareUsagePerWeekAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareUsagePerWeekAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareUsagePerWeekGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareUsagePerWeekGetAllByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareUsagePerWeekGetAllByComputerIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareUsagePerWeekGetAllByComputerIDUserIDSoftwareID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareUsagePerWeekGetByComputerIDUserIDSoftwareIDStartOfWeek', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareUsagePerWeekPutByComputerIDUserIDSoftwareIDStartOfWeek', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareUsagePerWeekRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareUsagePerWeekRemoveAllByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareUsagePerWeekRemoveAllByComputerIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareUsagePerWeekRemoveAllByComputerIDUserIDSoftwareID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareUsagePerWeekRemoveByComputerIDUserIDSoftwareIDStartOfWeek', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareUsagePerWeekReplaceSubsetByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareUsagePerWeekReplaceSubsetByComputerIDUserID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareUsagePerWeekReplaceSubsetByComputerIDUserIDSoftwareID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareUsagePerWeekSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareUsagePerWeekTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareUsagePerWeekUpdateBatchByComputerIDUserIDSoftwareIDStartOfWeek', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareUsagePerWeekUpdateByComputerIDUserIDSoftwareIDStartOfWeek', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareVersionAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareVersionAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareVersionBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareVersionGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareVersionGetAllBySoftwareName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareVersionGetAllBySoftwareProductID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareVersionGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareVersionGetBySoftwareNameVersion', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareVersionRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareVersionRemoveAllBySoftwareName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareVersionRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareVersionRemoveBySoftwareNameVersion', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareVersionReplaceSubsetBySoftwareName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareVersionSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareVersionTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareVersionUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('SoftwareVersionUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetedPackageAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetedPackageAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetedPackageGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetedPackageGetAllByTargetOUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetedPackageGetAllByTargetOUIDTargetTypeID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetedPackageGetAllByTargetOUIDTargetTypeIDTargetID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetedPackageGetAllByTargetOUIDTargetTypeIDTargetIDPackagePathID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetedPackageGetByTargetOUIDTargetTypeIDTargetIDPackagePathIDPolicyGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetedPackagePutByTargetOUIDTargetTypeIDTargetIDPackagePathIDPolicyGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetedPackageRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetedPackageRemoveAllByTargetOUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetedPackageRemoveAllByTargetOUIDTargetTypeID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetedPackageRemoveAllByTargetOUIDTargetTypeIDTargetID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetedPackageRemoveAllByTargetOUIDTargetTypeIDTargetIDPackagePathID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetedPackageRemoveByTargetOUIDTargetTypeIDTargetIDPackagePathIDPolicyGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetedPackageReplaceSubsetByDomainID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetedPackageReplaceSubsetByParentOrganisation', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetedPackageReplaceSubsetByTargetOUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetedPackageReplaceSubsetByTargetOUIDTargetTypeID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetedPackageReplaceSubsetByTargetOUIDTargetTypeIDTargetID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetedPackageReplaceSubsetByTargetOUIDTargetTypeIDTargetIDPackagePathID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetedPackageSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetedPackageTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetedPackageUpdateBatchByTargetOUIDTargetTypeIDTargetIDPackagePathIDPolicyGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetedPackageUpdateByTargetOUIDTargetTypeIDTargetIDPackagePathIDPolicyGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetedPolicyOUs', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetTypeBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetTypeGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetTypeGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TargetTypeGetByName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskGetByName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskPutByName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskRemoveByName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskScheduleAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskScheduleAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskScheduleGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskScheduleGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskScheduleRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskScheduleRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskScheduleSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskScheduleTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskScheduleUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskScheduleUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskTypeBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskTypeGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskTypeGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskTypeGetByName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskUpdateBatchByName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('TaskUpdateByName', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UnknownFileAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UnknownFileAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UnknownFileGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UnknownFileGetAllByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UnknownFileGetAllByComputerIDMD5', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UnknownFileGetByComputerIDFilename', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UnknownFilePutByComputerIDFilename', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UnknownFileRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UnknownFileRemoveAllByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UnknownFileRemoveAllByComputerIDMD5', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UnknownFileRemoveByComputerIDFilename', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UnknownFileReplaceSubsetByComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UnknownFileReplaceSubsetByComputerIDMD5', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UnknownFileSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UnknownFileTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UnknownFileUpdateBatchByComputerIDFilename', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UnknownFileUpdateByComputerIDFilename', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UpdateHardwareInventoryInitialize', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UpdateHardwareInventoryMaxOccurrence', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UpdateHardwareInventorySchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UpdateHardwareInventorySync', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UpdateInstallation', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UpdateNetworkDevices', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UpdateSoftwareInventoryInitialize', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UpdateSoftwareInventorySchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UpdateSoftwareInventorySync', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UpdateSoftwareVersion', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UpdateUsageData', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UserAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UserAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UserBind', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UserComputerList', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UserGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UserGetAllByDomainID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UserGetAllByGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UserGetAllByOUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UserGetByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UserGetByOUIDCN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UserInstallDetails', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UserPutByOUIDCN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UserRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UserRemoveAllByGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UserRemoveAllByOUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UserRemoveByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UserRemoveByOUIDCN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UserReplaceSubsetByGUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UserReplaceSubsetByOUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UserSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UserSummaryList', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UserTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UserUpdateBatchByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UserUpdateBatchByOUIDCN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UserUpdateByID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('UserUpdateByOUIDCN', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANDistributionJobAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANDistributionJobAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANDistributionJobGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANDistributionJobGetByDistJobUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANDistributionJobPutByDistJobUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANDistributionJobRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANDistributionJobRemoveByDistJobUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANDistributionJobSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANDistributionJobTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANDistributionJobUpdateBatchByDistJobUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANDistributionJobUpdateByDistJobUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANEffectivePolicy', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANStatusAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANStatusAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANStatusGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANStatusGetAllByDistJobUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANStatusGetByDistJobUIDComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANStatusPutByDistJobUIDComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANStatusRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANStatusRemoveAllByDistJobUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANStatusRemoveByDistJobUIDComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANStatusReplaceSubsetByDistJobUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANStatusSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANStatusTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANStatusUpdateBatchByDistJobUIDComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANStatusUpdateByDistJobUIDComputerID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANTaskAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANTaskAddBatch', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANTaskDetails', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANTaskDetailsGraph', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANTaskGetAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANTaskGetByTaskUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANTaskPutByTaskUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANTaskRemoveAll', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANTaskRemoveByTaskUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANTasks', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANTaskSchema', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANTaskTempAdd', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANTaskUpdateBatchByTaskUID', 'procedure');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANTaskUpdateByTaskUID', 'procedure');
-- VIEWS --
INSERT INTO ManageSoftMigration VALUES ('ComputerWithDN', 'view');
INSERT INTO ManageSoftMigration VALUES ('LicenseFull', 'view');
INSERT INTO ManageSoftMigration VALUES ('OrganizationFull', 'view');
INSERT INTO ManageSoftMigration VALUES ('PackageVersionFull', 'view');
INSERT INTO ManageSoftMigration VALUES ('PatchToProductAndOS', 'view');
INSERT INTO ManageSoftMigration VALUES ('SDOU', 'view');
INSERT INTO ManageSoftMigration VALUES ('V6DistributedPackage', 'view');
INSERT INTO ManageSoftMigration VALUES ('V6InstallationStatus', 'view');
INSERT INTO ManageSoftMigration VALUES ('V6PackageVersion', 'view');
INSERT INTO ManageSoftMigration VALUES ('V6SoftwareOccurrence', 'view');
INSERT INTO ManageSoftMigration VALUES ('WakeOnLANHostInfo', 'view');



set ARITHABORT ON
set QUOTED_IDENTIFIER OFF
go
-- DROP all stored procedure and views
DECLARE cleanup CURSOR FOR
	SELECT	'/*3*/ DROP PROCEDURE '+p.name AS cmd
	FROM	sysobjects AS p,
		ManageSoftMigration as m
	WHERE	p.xtype = 'P'
	  AND	(p.name NOT LIKE 'sp_%' OR p.name NOT LIKE 'xp_%' OR p.name NOT LIKE 'dt_%')
	  AND	p.name = m.name
	  AND	m.type = 'procedure'
	UNION
	SELECT	'/*6*/ DROP VIEW ['+v.name + ']' AS cmd
	FROM	sysobjects AS v,
		ManageSoftMigration as m
	WHERE	xtype = 'V'
	  AND	status >= 0
	  AND	v.name = m.name
	  AND	m.type = 'view'
	ORDER BY cmd

open cleanup
declare @clean AS varchar(256)
fetch NEXT FROM cleanup INTO @clean
while @@fetch_status = 0
begin
	print @clean
	exec(@clean)
	fetch NEXT FROM cleanup INTO @clean
end
close cleanup
deallocate cleanup

set ARITHABORT OFF
set QUOTED_IDENTIFIER ON
go

-----------------------------------------------------------------------
-- Perform other migration tasks
-----------------------------------------------------------------------

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'Language'
)
BEGIN
	PRINT 'Removing existing Language table'

	IF EXISTS (
		SELECT *
		FROM INFORMATION_SCHEMA.TABLES
		WHERE TABLE_NAME = 'SecurityPatch'
	)
	BEGIN
		IF EXISTS (
			SELECT *
			FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
			WHERE CONSTRAINT_NAME = 'FK_SecurityPatch_Language'
		)
		BEGIN
			ALTER TABLE SecurityPatch
				DROP CONSTRAINT FK_SecurityPatch_Language
		END
	END
	IF EXISTS (
		SELECT *
		FROM INFORMATION_SCHEMA.TABLES
		WHERE TABLE_NAME = 'SecurityPatchResource'
	)
	BEGIN
		IF EXISTS (
			SELECT *
			FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
			WHERE CONSTRAINT_NAME = 'FK_SecurityPatchResource_Language'
		)
		BEGIN
			ALTER TABLE SecurityPatchResource
				DROP CONSTRAINT FK_SecurityPatchResource_Language
		END
	END
	DROP TABLE [Language]
END
GO


-- Copy data from PackageVersion into a temporary table to migrate data
IF EXISTS (
	SELECT * FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'PackageVersion'
)
BEGIN
	PRINT 'Creating PackageVersion migration data'
	CREATE TABLE Old_PackageVersion (
		PackageVersionID	int NOT NULL,
		PackagePathID		int NOT NULL,
		Version			nvarchar(32) NOT NULL,
		[Update]		nvarchar(64) NOT NULL DEFAULT '',
		ArchitectureID		int,
		PackageFamilyID		int NOT NULL,
		Title			nvarchar(64) NULL,
		MD5			nvarchar(40) NULL,
		[Size]			int NULL,
		Category		nvarchar(128) NULL
	)
	INSERT	Old_PackageVersion(
		PackageVersionID, PackagePathID, Version,
		[Update], ArchitectureID, PackageFamilyID,
		Title, MD5, [Size], Category
	)
	SELECT	PackageVersionID,
		PackagePathID, Version,
		[Update], ArchitectureID, PackageFamilyID,
		Title, MD5, [Size], Category
	FROM	PackageVersion
END
GO


IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'PackageVersion'
)
BEGIN
	PRINT 'Removing the Architecture column from PackageVersion'
	
	IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE WHERE CONSTRAINT_NAME = 'FK_PackageVersion_Architecture')
		BEGIN ALTER TABLE PackageVersion DROP CONSTRAINT FK_PackageVersion_Architecture END
	IF EXISTS (SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE WHERE CONSTRAINT_NAME = 'PK_PackageVersion')
		BEGIN ALTER TABLE PackageVersion DROP CONSTRAINT PK_PackageVersion END
	-- get rid of the default on the column before dropping it
	DECLARE @defname nvarchar(128)
	SELECT @defname=name FROM dbo.sysobjects
	WHERE id IN
	(
		SELECT cdefault from dbo.syscolumns 
		WHERE 	id = object_id(N'[dbo].[PackageVersion]') 
		AND	name = 'ArchitectureID'
	)
	DECLARE @command nvarchar(128)
	SELECT @command = 'ALTER TABLE PackageVersion DROP CONSTRAINT ' + @defname
	FROM PackageVersion
	exec (@command)

	-- Ensure we only have a single PackageVersion for each
	-- PackagePathID, Version and Update value. If we have
	-- duplicates (with different ArchitectureID values), the
	-- version with the lowest ID is retained and others are
	-- deleted.

	DECLARE pv_cur CURSOR FOR
	SELECT MIN(pv1.PackageVersionID), pv2.PackageVersionID
	FROM	PackageVersion pv1
		INNER JOIN PackageVersion pv2
			ON pv2.PackageVersionID > pv1.PackageVersionID
			AND pv2.PackagePathID = pv1.PackagePathID
			AND pv2.Version = pv1.Version
			AND pv2.[Update] = pv1.[Update]
	GROUP BY pv2.PackageVersionID

	OPEN pv_cur
	DECLARE @keepPVID INT
	DECLARE @removePVID INT
	FETCH NEXT FROM pv_cur INTO @keepPVID, @removePVID
	WHILE @@FETCH_STATUS = 0
	BEGIN
		DELETE FROM PackageProvides
		WHERE	PackageVersionID = @removePVID
			AND EXISTS (
				SELECT	*
				FROM	PackageProvides pp2
				WHERE	pp2.PackageFamilyID = PackageProvides.PackageFamilyID
					AND pp2.Version = PackageProvides.Version
					AND pp2.PackageVersionID = @keepPVID
			)
		UPDATE PackageProvides SET PackageVersionID = @keepPVID WHERE PackageVersionID = @removePVID

		DELETE FROM PackageRequires
		WHERE	PackageVersionID = @removePVID
			AND EXISTS (
				SELECT	*
				FROM	PackageRequires pr2
				WHERE	pr2.RequiredType = PackageRequires.RequiredType
					AND pr2.RequiredObject = PackageRequires.RequiredObject
					AND pr2.Match = PackageRequires.Match
					AND pr2.PackageVersionID = @keepPVID
			)
		UPDATE PackageRequires SET PackageVersionID = @keepPVID WHERE PackageVersionID = @removePVID

		DELETE FROM MediaContainsPackageVersion
		WHERE	PackageVersionID = @removePVID
			AND EXISTS (
				SELECT	*
				FROM	MediaContainsPackageVersion mcpv2
				WHERE	mcpv2.MediaID = MediaContainsPackageVersion.MediaID
					AND mcpv2.PackageVersionID = @keepPVID
			)
		UPDATE MediaContainsPackageVersion SET PackageVersionID = @keepPVID WHERE PackageVersionID = @removePVID

		DELETE FROM Installation
		WHERE	PackageVersionID = @removePVID
			AND EXISTS (
				SELECT	*
				FROM	Installation i2
				WHERE	i2.ComputerID = Installation.ComputerID
					AND i2.UserID = Installation.UserID
					AND i2.PackageVersionID = @keepPVID
			)
		UPDATE Installation SET PackageVersionID = @keepPVID WHERE PackageVersionID = @removePVID

		DELETE FROM InstallationHistory
		WHERE	PackageVersionID = @removePVID
			AND EXISTS (
				SELECT	*
				FROM	InstallationHistory ih2
				WHERE	ih2.ComputerID = InstallationHistory.ComputerID
					AND ih2.UserID = InstallationHistory.UserID
					AND ih2.Reported = InstallationHistory.Reported
					AND ih2.PackageVersionID = @keepPVID
			)
		UPDATE InstallationHistory SET PackageVersionID = @keepPVID WHERE PackageVersionID = @removePVID

		DELETE FROM DistributedPackage
		WHERE	RequestedVersionID = @removePVID
			AND EXISTS (
				SELECT	*
				FROM	DistributedPackage dp2
				WHERE	dp2.ServerUID = DistributedPackage.ServerUID
					AND dp2.RequestedVersionID = @keepPVID
			)
		UPDATE DistributedPackage SET ConfirmedVersionID = @keepPVID WHERE ConfirmedVersionID = @removePVID
		UPDATE DistributedPackage SET RequestedVersionID = @keepPVID WHERE RequestedVersionID = @removePVID

		UPDATE Action SET PackageVersionID = @keepPVID WHERE PackageVersionID = @removePVID

		DELETE FROM PackageVersion
		WHERE PackageVersionID = @removePVID

		FETCH NEXT FROM pv_cur INTO @keepPVID, @removePVID
	END
	CLOSE pv_cur
	DEALLOCATE pv_cur

	-- Remove the default constraint so we can drop the column:
	DECLARE @cmd varchar(1024)
	SELECT @cmd = 'ALTER TABLE PackageVersion DROP CONSTRAINT '
		+ QuoteName(Object_Name(c.cdefault))
	FROM syscolumns AS c
	WHERE name = 'ArchitectureID'
	  AND c.id = object_ID('PackageVersion')
	-- print @cmd
	EXEC(@cmd)

	ALTER TABLE PackageVersion DROP COLUMN ArchitectureID

	ALTER TABLE PackageVersion ADD CONSTRAINT PK_PackageVersion
		PRIMARY KEY NONCLUSTERED
		(PackagePathID, Version, [Update])
END
GO

-- ADComputer and ADUser tables have changed. They contain only recoverable data.
DROP TABLE ADComputer
DROP TABLE ADUser
DROP TABLE ManageSoftMigration

